# -*- coding: utf-8 -*-

#version de Python
import sys
print(sys.version)

#changer le répertoire courant
import os
os.chdir("D:/DataMining/Databases_for_mining/dataset_for_soft_dev_and_comparison/h2o")

#charger les données
import pandas
wave = pandas.read_table("wave100k.txt",sep="\t",decimal=".",header=0)

#vérification
print(wave.info())

#outil pour mesurer le temps
import timeit
print(dir(timeit))

#importation de la librairie H2O
import h2o

#vérification de version
print(h2o.__version__)

#démarage de la machine "h2o"
h2o.init(nthreads = 1)

#typage du data frame au format h2o
h2owave = h2o.H2OFrame(wave)

#importation de la régression généralisée
from h2o.estimators import H2OGeneralizedLinearEstimator

#instanciation - régression logistique multinomiale
modelH2o = H2OGeneralizedLinearEstimator(family="multinomial")

#apprentissage -- mesure du temps de calcul
depart = timeit.default_timer()
modelH2o.train(h2owave.columns[1:],"onde",training_frame=h2owave)
duree = timeit.default_timer()- depart
print(str(duree)+" sec.")

#affichage matrice de confusion
modelH2o.confusion_matrix(h2owave)

#éteindre le moteur "h2o"
h2o.cluster().shutdown()

#################################################
#### EXPERIMENTATION - NOMBRE DE THREADS ########
#################################################

#démarrage du moteur h2o
#spécification du nombre de threads à utiliser
h2o.init(nthreads=1)
#h2o.init(nthreads=4)
#h2o.init(nthreads=8)

#typage du data frame au format h2o
h2owave = h2o.H2OFrame(wave)

#régression logistique
from h2o.estimators import H2OGeneralizedLinearEstimator

#random forest
#from h2o.estimators import H2ORandomForestEstimator

#gradient boosting
#from h2o.estimators import H2OGradientBoostingEstimator

#naive bayes
#from h2o.estimators import H2ONaiveBayesEstimator

#perceptron multicouche
#from h2o.estimators import H2ODeepLearningEstimator

#comptabilisation temps moyen
temps = 0.0

#répétition
for i in range(10):
    #instanciation
    modelH2o = H2OGeneralizedLinearEstimator(family="multinomial")
    #modelH2o = H2ORandomForestEstimator()
    #modelH2o = H2OGradientBoostingEstimator()
    #modelH2o = H2ONaiveBayesEstimator()
    #modelH2o = H2ODeepLearningEstimator(hidden=[2],activation="Tanh",distribution = "multinomial")
    #apprentissage
    depart = timeit.default_timer()
    modelH2o.train(h2owave.columns[1:],"onde",training_frame=h2owave)
    duree = timeit.default_timer()- depart
    print(str(duree)+" sec.")
    #addition du temps
    temps = temps + duree    
    #affichage matrice de confusion
    modelH2o.confusion_matrix(h2owave)
    
#temps moyen
temps = temps / 10.0
print(temps)

#éteindre le moteur "h2o"
h2o.cluster().shutdown()
